pub enum Command {
Queries {
conn: ConnectArgs,
sort_by: QueriesSortBy,
filter: QueriesFilterArgs,
limit: usize,
},
Total {
conn: ConnectArgs,
filter: QueriesFilterArgs,
},
Inspect {
conn: ConnectArgs,
fingerprint: u64,
filter: QueriesFilterArgs,
},
Errors {
conn: ConnectArgs,
filter: ErrorFilterArgs,
limit: usize,
},
Context {
command: ContextCommand,
},
}Expand description
Subcommands for different analysis modes.
Variants
Queries
Show top queries grouped by normalized_query_hash, with optional filters and sorting.
Fields
conn: ConnectArgssort_by: QueriesSortByField to sort queries by in top results, descending order.
filter: QueriesFilterArgsTotal
Analyze total number of queries and aggregated statistics (e.g. read rows/data) in a time range.
This command shows cumulative metrics over the specified filter window, helping track overall workload volume.
Inspect
Inspect a single query fingerprint with detailed info.
This command streams all log entries matching the specified query fingerprint, applying optional filters such as time ranges or users. It provides a detailed view of the query’s resource usage, execution times, affected tables, and more.
Errors
Show top ClickHouse query errors with filtering options.
Context
Manage context profiles used for connecting to ClickHouse.
Fields
command: ContextCommandTrait Implementations
Sourceimpl FromArgMatches for Command
impl FromArgMatches for Command
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Subcommand for Command
impl Subcommand for Command
Sourcefn augment_subcommands<'b>(__clap_app: Command) -> Command
fn augment_subcommands<'b>(__clap_app: Command) -> Command
Sourcefn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
fn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Self can parse a specific subcommand