ClickHouse context manager for handling connection profiles.
This module provides functionality for managing multiple ClickHouse connection profiles, storing credentials securely, and persisting configuration in a TOML file.
Each profile stores information like username, password (kept in the system keyring), ClickHouse URLs, and TLS certificate options.
Configuration Path
By default, the configuration is saved in a platform-specific config directory,
e.g. on Linux: ~/.config/clickcheck/config.toml.
Profiles
Profiles can be created, modified, and selected as the default. Credentials
are stored securely using the keyring crate.
Structs
- Context
- Manages ClickHouse connection profiles.