Handles output formatting and printing for different data types in the CLI.
Supports output formats: plain text (human-readable), JSON, and YAML.
Functions
- print_
context_ config_ path - Prints the file path to the context configuration.
- print_
context_ current - Prints the name of the currently active context profile, or an empty message if none is set.
- print_
context_ list - Prints a list of available context profile names.
- print_
context_ profile - Prints a detailed description of a single context profile.
- print_
query_ extended - print_
top_ errors - Prints the most frequent errors observed in
system.errors. - print_
top_ queries - Prints the top heaviest queries in the selected output format.
- print_
total_ queries - Prints the total weights of queries aggregated over a period of time.